%global srcname docutils

Name:		python-%{srcname}
Summary:	Python Documentation Utilities
Version:	0.10
Release:	%mkrel 0.svn7502.2
URL:		http://docutils.sourceforge.net/
License:	Public Domain and BSD and Python and GPLv3+
Group:		Development/Python
#Source:		http://downloads.sourceforge.net/project/docutils/docutils/%{version}/%{srcname}-%{version}.tar.gz
# Sometimes we need snapshots.  Instructions below:
# svn co -r 7502 https://docutils.svn.sourceforge.net/svnroot/docutils/trunk/docutils
# cd docutils
# python setup.py sdist
# The tarball is in dist/docutils-VERSION.tar.gz
Source:		%{srcname}-%{version}.tar.gz
# from Fedora
# Submitted upstream: https://sourceforge.net/tracker/index.php?func=detail&aid=3560841&group_id=38414&atid=422030
Patch0: docutils-__import__-tests.patch
Patch1: docutils-__import__-fixes2.patch

# Disable some tests known to fail with Python 3.3
# Bug reports filed upstream as:
#   https://sourceforge.net/tracker/?func=detail&aid=3555164&group_id=38414&atid=422030
# and:
#   http://sourceforge.net/tracker/?func=detail&aid=3561133&group_id=38414&atid=422030
# Unicode test is failing because of a python3.3b2 bug:
# ImportError(b'str').__str__() returns bytes rather than str
# http://bugs.python.org/issue15778
Patch100: disable-failing-tests.patch

BuildArch:	noarch
BuildRequires:	python-devel, emacs
BuildRequires:	python-setuptools
Suggests:	python-imaging

%description
The Docutils project specifies a plaintext markup language, reStructuredText,
which is easy to read and quick to write.  The project includes a python
library to parse rST files and transform them into other useful formats such
as HTML, XML, and TeX as well as commandline tools that give the enduser
access to this functionality.

Currently, the library supports parsing rST that is in standalone files and
PEPs (Python Enhancement Proposals).  Work is underway to parse rST from
Python inline documentation modules and packages.

%package -n python3-%{srcname}
Summary:	System for processing plaintext documentation for python3
Group:		Development/Python
BuildRequires:	python3-devel
BuildRequires:	python3-setuptools

%description -n python3-%{srcname}
The Docutils project specifies a plaintext markup language, reStructuredText,
which is easy to read and quick to write.  The project includes a python
library to parse rST files and transform them into other useful formats such
as HTML, XML, and TeX as well as commandline tools that give the enduser
access to this functionality.

Currently, the library supports parsing rST that is in standalone files and
PEPs (Python Enhancement Proposals).  Work is underway to parse rST from
Python inline documentation modules and packages.

This package contains the module, ported to run under python3.

%prep
%setup -q -c
pushd %{srcname}-%{version}
%patch0 -p0
%patch1 -p0
%patch100 -p1 -b .disable-failing-tests
# Remove shebang from library files
for file in docutils/utils/{code_analyzer.py,punctuation_chars.py,error_reporting.py} docutils/utils/math/{latex2mathml.py,math2html.py} docutils/writers/xetex/__init__.py; do
sed -i -e '/#! *\/usr\/bin\/.*/{1D}' $file
done
popd

mv %{srcname}-%{version} python2
cp -r python2 python3

%build
pushd python2
CFLAGS="$RPM_OPT_FLAGS" %{__python} setup.py build
popd

pushd python3
CFLAGS="$RPM_OPT_FLAGS" %{__python3} setup.py build
popd

%install
%__rm -rf %{buildroot}
# Must do the python3 install first because the scripts in /usr/bin are
# overwritten by setup.py install (and we want the python2 version to be the
# default for now).
pushd python3
%{__python3} setup.py install --skip-build  --root=%{buildroot}

# docutils setup.py runs 2to3 on a copy of the tests and puts it in sitelib.
rm -rf %{buildroot}%{python3_sitelib}/test

popd
rm -rf %{buildroot}%{_bindir}/*

pushd python2
%{__python} setup.py install --skip-build --root %{buildroot}

for file in %{buildroot}%_bindir/*.py; do
  mv $file %{buildroot}%_bindir/`basename $file .py`
done

# We want the licenses but don't need this build file
rm -f licenses/docutils.conf

# Make emacs mode available:
emacs -batch -f batch-byte-compile tools/editors/emacs/rst.el
%__install -d -m 755 %{buildroot}%{_datadir}/emacs/site-lisp
%__install -D -m 644 tools/editors/emacs/rst.el* %{buildroot}%{_datadir}/emacs/site-lisp
%__rm -rf tools/editors/emacs

cat > ./rst.el << EOF
(autoload 'rst-mode "rst" "reStructuredText mode" t)
(add-to-list 'auto-mode-alist '("\\.rst$" . rst-mode))
EOF
emacs -batch -f batch-byte-compile rst.el
%__install -d -m 755 %{buildroot}%{_sysconfdir}/emacs/site-start.d
%__install -m 644 rst.el* %{buildroot}%{_sysconfdir}/emacs/site-start.d/

popd

%check
pushd python2
python test/alltests.py
popd
pushd python3
python3 test3/alltests.py
popd

%files
%defattr(-,root,root,-)
%doc python2/BUGS.txt python2/COPYING.txt python2/FAQ.txt python2/HISTORY.txt  
%doc python2/README.txt python2/RELEASE-NOTES.txt python2/THANKS.txt 
%doc python2/licenses python2/docs python2/tools/editors
%{_bindir}/*
%{python_sitelib}/*
%_datadir/emacs/site-lisp/*
%_sysconfdir/emacs/site-start.d/*

%files -n python3-%{srcname}
%defattr(-,root,root,-)
%doc python3/BUGS.txt python3/COPYING.txt python3/FAQ.txt python3/HISTORY.txt  
%doc python3/README.txt python3/RELEASE-NOTES.txt python3/THANKS.txt 
%doc python3/licenses python3/docs python3/tools/editors
%{python3_sitelib}/*



%changelog

* Sun Jan 13 2013 umeabot <umeabot> 0.10-0.svn7502.2.mga3
+ Revision: 378760
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 philippem <philippem> 0.10-0.svn7502.1.mga3
+ Revision: 339979
- Update to new upstream

* Tue Sep 04 2012 philippem <philippem> 0.9.1-1.mga3
+ Revision: 288134
- New upstream release 0.9.1

* Sat Oct 22 2011 philippem <philippem> 0.8.1-1.mga2
+ Revision: 157386
- new version 0.8.1

* Mon Jan 31 2011 dmorgan <dmorgan> 0.7-4.mga1
+ Revision: 45389
- Rebuild because of missing provides

* Mon Jan 17 2011 misc <misc> 0.7-3.mga1
+ Revision: 21017
- rebuilt for new python

* Thu Jan 13 2011 ahmad <ahmad> 0.7-2.mga1
+ Revision: 8311
- imported package python-docutils

